# Contributors

## Project Lead

* [Bradley Nedrud](https://github.com/bwnedrud)

## Individual Contributors

* [amruta3991](https://github.com/amruta3991)
* [apasarka](https://github.com/apasarka)
* [asamaiya](https://github.com/asamaiya)
* [chenchienjacklin](https://github.com/chenchienjacklin)
* [drewm102](https://github.com/drewm102)
* [Hiroki](https://github.com/hiro727)
* [Isaac Waldron](https://github.com/isaacwaldron)
* [Karan Bhagat](https://github.com/kbhagat-ansys)
* [Kathy Pippert](https://github.com/PipKat)
* [Maxime Rey](https://github.com/MaxJPRey)
* [Minsi Sung](https://github.com/ansminsisung)
* [Roberto Pastor Muela](https://github.com/RobPasMue)
* [SitaRamesh](https://github.com/SitaRamesh)
* [SriniSundararajan](https://github.com/SriniSundararajan)
* [svandenb-dev](https://github.com/svandenb-dev)
* [Sébastien Morais](https://github.com/SMoraisAnsys)
* [vamartid](https://github.com/vmartidis)
